MediaFormat

Struct MediaFormat 

pub struct MediaFormat {
    media_kind: MediaKind,
    codec: MediaCodec,
    payload_type: PayloadType,
    clock_rate: u32,
    channels: Option<u16>,
    settings: Vec<CodecSetting>,
    rtcp_feedback: Vec<RtcpFeedback>,
}
Negotiated codec format for a concrete media stream.

Unlike a capability, a format has a fixed payload_type that matches the actual value expected in the RTP packets on the wire.

Fields

media_kind: MediaKindcodec: MediaCodecpayload_type: PayloadTypeclock_rate: u32channels: Option<u16>settings: Vec<CodecSetting>rtcp_feedback: Vec<RtcpFeedback>

Implementations

Source

impl MediaFormat

pub fn new( media_kind: MediaKind, codec: impl Into<MediaCodec>, payload_type: PayloadType, clock_rate: u32, ) -> Self

pub fn with_channels(self, channels: u16) -> Self

pub fn with_setting(self, setting: CodecSetting) -> Self

pub fn with_parameter( self, name: impl Into<String>, value: impl Into<String>, ) -> Self

pub fn with_rtcp_feedback(self, feedback: RtcpFeedback) -> Self

pub fn media_kind(&self) -> MediaKind

pub fn codec(&self) -> &MediaCodec

pub fn codec_name(&self) -> &str

pub fn payload_type_id(&self) -> PayloadType

pub fn payload_type(&self) -> u8

pub fn clock_rate(&self) -> u32

pub fn channels(&self) -> Option<u16>

pub fn settings(&self) -> impl Iterator<Item = &CodecSetting>

pub fn parameters(&self) -> impl Iterator<Item = (String, String)> + '_

pub fn rtcp_feedback(&self) -> impl Iterator<Item = &RtcpFeedback>

pub fn rtx_associated_payload_type_id(&self) -> Option<PayloadType>

pub fn rtx_associated_payload_type(&self) -> Option<u8>