pub struct Rid(String);Expand description
Restriction identifier (RFC 8851).
Used in “Simulcast” to label different encodings of the same source (e.g. “low” and “high” resolution). Unlike SSRC which is a random number that can change if a collision occurs, RID is a stable string label.
Tuple Fields
0: StringImplementations
Sourceimpl Rid
impl Rid
pub fn try_new(value: impl Into<String>) -> Option<Rid>
Sourcepub fn new(value: impl Into<String>) -> Rid
pub fn new(value: impl Into<String>) -> Rid
Builds a RID using the RFC 8851 rid-id grammar corrected by RFC Editor errata 7132.
Panics
Panics when value is empty, too long or contains a non-alphanumeric
byte.
pub fn as_str(&self) -> &str